# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"imageFromS3": "Images.ipynb",
         "imageFromUrl": "Images.ipynb",
         "imageToS3": "Images.ipynb",
         "resizeImage": "Images.ipynb",
         "showImgS3": "Images.ipynb",
         "printDict": "dictUtil.ipynb",
         "allKeysInDict": "dictUtil.ipynb",
         "errorString": "exception.ipynb",
         "getSecret": "secrets.ipynb",
         "shorten": "shortenLInk.ipynb",
         "url": "shortenLInk.ipynb",
         "add_method": "wrappers.ipynb"}

modules = ["images.py",
           "dictUtil.py",
           "exception.py",
           "secrets.py",
           "shortenLink.py",
           "wrappers.py"]

doc_url = "https://thanakijwanavit.github.io/nicHelper/"

git_url = "https://github.com/thanakijwanavit/nicHelper/tree/master/"

def custom_doc_links(name): return None
